@@ -154,19 +154,22 @@ def disk_to_mbtiles(directory_path, mbtiles_file, **kwargs):
                 for x in xs:
                     for r2, ignore, ys in os.walk(os.path.join(r1, z, x)):
                         for y in ys:
-                            if (y.endswith(image_format)):
-                                f = open(os.path.join(r1, z, x, y), 'rb')
+                            y, ext = y.split('.', 1)
+                            if (ext == image_format):
+                                f = open(os.path.join(r1, z, x, y+'.'+ext), 'rb')
+                                if kwargs.get('scheme') == 'xyz':
+                                    y = flip_y(int(z), int(y))
                                 cur.execute("""insert into tiles (zoom_level,
                                     tile_column, tile_row, tile_data) values
                                     (?, ?, ?, ?);""",
-                                    (z, x, y.split('.')[0], sqlite3.Binary(f.read())))
+                                    (z, x, y, sqlite3.Binary(f.read())))
                                 f.close()
                                 count = count + 1
                                 if (count % 100) == 0:
                                     for c in msg: sys.stdout.write(chr(8))
                                     msg = "%s tiles inserted (%d tiles/sec)" % (count, count / (time.time() - start_time))
                                     sys.stdout.write(msg)
-                            elif (y.endswith('grid.json')):
+                            elif (ext == 'grid.json'):
                                 if grid_warning:
                                     logger.warning('grid.json interactivity import not yet supported\n')
                                     grid_warning= False
@@ -184,10 +187,7 @@ def mbtiles_to_disk(mbtiles_file, directory_path, **kwargs):
     done = 0
     msg = ''
     service_version = metadata.get('version', '1.0.0')
-    base_path = os.path.join(directory_path,
-                                service_version,
-                                metadata.get('name', 'layer')
-                            )
+    base_path = directory_path
     if not os.path.isdir(base_path):
         os.makedirs(base_path)
 
@@ -204,7 +204,7 @@ def mbtiles_to_disk(mbtiles_file, directory_path, **kwargs):
         z = t[0]
         x = t[1]
         y = t[2]
-        if kwargs.get('scheme') == 'osm':
+        if kwargs.get('scheme') == 'xyz':
           y = flip_y(z,y)
           print 'flipping'
         tile_dir = os.path.join(base_path, str(z), str(x))
@@ -232,7 +232,12 @@ def mbtiles_to_disk(mbtiles_file, directory_path, **kwargs):
         zoom_level = g[0] # z
         tile_column = g[1] # x
         y = g[2] # y
-        if kwargs.get('scheme') == 'osm':
+        grid_data_cursor = con.execute('''select key_name, key_json FROM
+            grid_data WHERE
+            zoom_level = %(zoom_level)d and
+            tile_column = %(tile_column)d and
+            tile_row = %(y)d;''' % locals() )
+        if kwargs.get('scheme') == 'xyz':
           y = flip_y(zoom_level,y)
         grid_dir = os.path.join(base_path, str(zoom_level), str(tile_column))
         if not os.path.isdir(grid_dir):
@@ -241,11 +246,6 @@ def mbtiles_to_disk(mbtiles_file, directory_path, **kwargs):
         f = open(grid, 'w')
         grid_json = json.loads(zlib.decompress(g[3]))
         # join up with the grid 'data' which is in pieces when stored in mbtiles file
-        grid_data_cursor = con.execute('''select key_name, key_json FROM
-            grid_data WHERE
-            zoom_level = %(zoom_level)d and
-            tile_column = %(tile_column)d and
-            tile_row = %(tile_row)d;''' % locals())
         grid_data = grid_data_cursor.fetchone()
         data = {}
         while grid_data:
